# Generated by Django 2.0.1 on 2018-01-06 21:48

import django_crypto_fields.fields.encrypted_char_field
import django_crypto_fields.fields.encrypted_text_field
import edc_model.validators.phone
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("edc_locator", "0003_auto_20180103_1351")]

    operations = [
        migrations.AddField(
            model_name="historicalsubjectlocator",
            name="subject_work_cell",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text=" (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[edc_model.validators.phone.cell_number],
                verbose_name="Work contact cell number",
            ),
        ),
        migrations.AddField(
            model_name="subjectlocator",
            name="subject_work_cell",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text=" (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[edc_model.validators.phone.cell_number],
                verbose_name="Work contact cell number",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectlocator",
            name="subject_work_phone",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text=" (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[edc_model.validators.phone.telephone_number],
                verbose_name="Work contact telephone",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectlocator",
            name="subject_work_place",
            field=django_crypto_fields.fields.encrypted_text_field.EncryptedTextField(
                blank=True,
                help_text=" (Encryption: AES local)",
                max_length=250,
                null=True,
                verbose_name="Name and location of work place",
            ),
        ),
        migrations.AlterField(
            model_name="subjectlocator",
            name="subject_work_phone",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text=" (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[edc_model.validators.phone.telephone_number],
                verbose_name="Work contact telephone",
            ),
        ),
        migrations.AlterField(
            model_name="subjectlocator",
            name="subject_work_place",
            field=django_crypto_fields.fields.encrypted_text_field.EncryptedTextField(
                blank=True,
                help_text=" (Encryption: AES local)",
                max_length=250,
                null=True,
                verbose_name="Name and location of work place",
            ),
        ),
    ]
