# Generated by Django 3.2.13 on 2022-09-22 19:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_locator", "0029_auto_20220826_0406"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsubjectlocator",
            name="may_call_work",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Has the participant given permission to be contacted <b>at work</b>, by telephone or cell, by study staff for follow-up purposes during the study?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectlocator",
            name="may_call_work",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Has the participant given permission to be contacted <b>at work</b>, by telephone or cell, by study staff for follow-up purposes during the study?",
            ),
        ),
    ]
